/**
 *    @file  json.h
 *   @brief  Wrapper around cJSON library with helpers
 *
 *  This library is only a simple wrapper around the cJSON library, providing
 *  helper functions.
 *
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  29/10/2024
 *      Revision:  none
 * Last modified:  2024-11-04 13:24
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifndef __JSON_H__
#define __JSON_H__

#include "cJSON.h"

/**
 *  @brief  Convert a cJSON object in a C String
 *
 *  @param  value_json the cJSON value to convert
 *  @return The C string conversion dynamically allocated.
 *      @retval NULL if there was a problem, such as an Out Of Memory
 *      @retval Pointer to a zero terminated C string.
 *
 *  It converts NULL values, String values, Integer values, Boolean values in C
 *  strings. If the value is an array, it is fully pretty printed. If the JSON
 *  value is nothing in this list, the function returns the "Invalid data"
 *  string.
 *
 *   The returned strings are allocated using malloc on the heap and should be
 *   freed by the calling application.
 */
char* json2text(cJSON* value_json);

#endif /* __JSON_H__ */
/* vim: set tw=80: */
